v0.6.0
======

Features
--------

- Refreshed and modernized the package.
- Require Python 3.8 or later.


0.5.0
=====

Added support for Python 3

0.4.3
=====

just a quick minor bugfix

0.4.2
=====

nothing has changed in how the scripts works but...

added easy_install / pip support and uploaded package to PyPI
using optparse for commandline options

0.4.1
=====

minor bugfix - fixed invalid script's homepage url (thanks RooToor!)

0.4
===

added template system

0.3
===

added sorting of files using jQuery

added dir-info

0.2.1
=====

small bugfix for Chrome browser

0.2
===

code cleanup

CSS tweaks

filetype recognition and different icons for different filetypes groups

0.1
===

initial release
